Overview
========
the ``ftw.dashboard.portlets.recentlymodified`` implements a
recentlyModified Portlet, which shows the last changes from a defined section.


Install
=======

- Add ``ftw.dashboard.portlets.recentlymodified`` to your buildout configuration

::

    [instance]
    eggs =
        ftw.dashboard.portlets.recentlymodified

- Run buildout

- Install ``ftw.dashboard.portlets.recentlymodified`` in portal_setup


Links
=====

- Package repository: https://github.com/4teamwork/ftw.dashboard.portlets.recentlymodified
- Issue tracker: https://github.com/4teamwork/ftw.dashboard.portlets.recentlymodified/issues
- Package on pypi: http://pypi.python.org/pypi/ftw.dashboard.portlets.recentlymodified
- Continuous integration: https://jenkins.4teamwork.ch/search/?q=ftw.dashboard.portlets.recentlymodified


Maintainer
==========

This package is produced and maintained by `4teamwork GmbH <http://www.4teamwork.ch/>`_.